mysql.util.string

Package mysql :: Package util :: Module string |
[hide private]
[frames] | no frames]

# Source Code for Module mysql.util.string

     1  # $Header: /home/cvs2/mysql/mysql/util/string.py,v 1.3 2006/08/26 20:19:52 ehuss Exp $
     2  # Copyright (c) 2006, Eric Huss
     3  # All rights reserved.
     4  #
     5  # Redistribution and use in source and binary forms, with or without
     6  # modification, are permitted provided that the following conditions are met:
     7  #
     8  # 1. Redistributions of source code must retain the above copyright notice,
     9  #    this list of conditions and the following disclaimer.
    10  # 2. Redistributions in binary form must reproduce the above copyright notice,
    11  #    this list of conditions and the following disclaimer in the documentation
    12  #    and/or other materials provided with the distribution.
    13  # 3. Neither the name of Eric Huss nor the names of any contributors may be
    14  #    used to endorse or promote products derived from this software without
    15  #    specific prior written permission.
    16  #
    17  # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
    18  # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
    19  # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
    20  # ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
    21  # LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
    22  # CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
    23  # SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
    24  # INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
    25  # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
    26  # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
    27  # POSSIBILITY OF SUCH DAMAGE.
    28
    29  """Internal string manipulation routines.
    30  """
    31
    32  __version__ = '$Revision: 1.3 $'
    33
    34  from mysql.util._c_only import escape
    35